package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.FormalTeacherClass;
import com.ruoyi.common.core.domain.entity.vo.FormalTeacherClassVo;

/**
 * 老师-班级（学科）(审核通过之后数据)Service接口
 * 
 * @author ruoyi
 * @date 2023-05-30
 */
public interface IFormalTeacherClassService 
{
    /**
     * 查询老师-班级（学科）(审核通过之后数据)
     * 
     * @param id 老师-班级（学科）(审核通过之后数据)主键
     * @return 老师-班级（学科）(审核通过之后数据)
     */
    public FormalTeacherClass selectFormalTeacherClassById(Long id);

    /**
     * 查询老师-班级（学科）(审核通过之后数据)列表
     * 
     * @param formalTeacherClass 老师-班级（学科）(审核通过之后数据)
     * @return 老师-班级（学科）(审核通过之后数据)集合
     */
    public List<FormalTeacherClass> selectFormalTeacherClassList(FormalTeacherClass formalTeacherClass);

    /**
     * 新增老师-班级（学科）(审核通过之后数据)
     * 
     * @param formalTeacherClass 老师-班级（学科）(审核通过之后数据)
     * @return 结果
     */
    public int insertFormalTeacherClass(FormalTeacherClass formalTeacherClass);

    /**
     * 修改老师-班级（学科）(审核通过之后数据)
     * 
     * @param formalTeacherClass 老师-班级（学科）(审核通过之后数据)
     * @return 结果
     */
    public int updateFormalTeacherClass(FormalTeacherClass formalTeacherClass);

    /**
     * 批量删除老师-班级（学科）(审核通过之后数据)
     * 
     * @param ids 需要删除的老师-班级（学科）(审核通过之后数据)主键集合
     * @return 结果
     */
    public int deleteFormalTeacherClassByIds(Long[] ids);

    /**
     * 删除老师-班级（学科）(审核通过之后数据)信息
     * 
     * @param id 老师-班级（学科）(审核通过之后数据)主键
     * @return 结果
     */
    public int deleteFormalTeacherClassById(Long id);

    public List<FormalTeacherClass> getTeacherClass(String teacherId);

    AjaxResult updateFormalTeacherClassList(FormalTeacherClassVo formalTeacherClassVo);
}
